@@ -6,7 +6,7 @@ from oddrn_generator.generators import FilesystemGenerator
 from odd_cli.client import Client
 from odd_cli.reader.reader import read
 from odd_cli.tokens import app as tokens_app
-from loguru import logger
+from logger import logger
 
 app = typer.Typer()
 app.add_typer(
